import { createRouter, createWebHashHistory } from 'vue-router'

const routes = [
  {
    path: '/',
    redirect: '/home'
  },
  {
    name: 'login',
    path: '/login',
    component: () => import('../views/login'),
    meta: {
      title: '登录',
    },
  },
  {
    name: 'home',
    path: '/home',
    component: () => import('../views/home'),
    meta: {
      title: '首页',
    },
  },
  {
    name: 'userInfo',
    path: '/userInfo',
    component: () => import('../views/userInfo'),
    meta: {
      title: '账号中心',
    },
  },
  {
    path: '/repair',
    component: () => import('../views/repair/index.vue'),
    children: [
      {
        name: 'repairOnline',
        path: 'create',
        component: () => import('../views/repair/create.vue'),
        meta: {
          title: '线上报修',
        },
      },
      {
        name: 'repairList',
        path: 'list',
        component: () => import('../views/repair/list.vue'),
        meta: {
          title: '工单待办',
        },
      },
      {
        name: 'repairDetail',
        path: 'detail',
        component: () => import('../views/repair/detail.vue'),
        meta: {
          title: '工单详情',
        },
      },
    ]
  },
  {
    path: '/review',
    component: () => import('../views/review/index.vue'),
    children: [
      {
        name: 'reviewRecord',
        path: 'list',
        component: () => import('../views/review/list.vue'),
        meta: {
          title: '巡检记录',
        },
      },
      {
        name: 'repairClock',
        path: 'create',
        component: () => import('../views/review/create.vue'),
        meta: {
          title: '巡检打卡',
        },
      },
    ]
  },
  {
    path: '/bill',
    component: () => import('../views/bill/index.vue'),
    children: [
      {
        name: 'billList',
        path: 'list',
        component: () => import('../views/bill/list.vue'),
        meta: {
          title: '租户账单',
        },
      },
      {
        name: 'billDetail',
        path: 'detail',
        component: () => import('../views/bill/detail.vue'),
        meta: {
          title: '账单明细',
        },
      },
    ]
  },
  {
    path: '/pay',
    component: () => import('../views/pay/index.vue'),
    children: [
      {
        name: 'payRecord',
        path: 'record',
        component: () => import('../views/pay/record.vue'),
        meta: {
          title: '扣缴记录',
        },
      },
      {
        name: 'payFee',
        path: 'fee',
        component: () => import('../views/pay/fee.vue'),
        meta: {
          title: '欠费待收',
        },
      },
    ]
  },
  {
    path: '/device',
    component: () => import('../views/device/index.vue'),
    children: [
      {
        name: 'deviceAlarm',
        path: 'list',
        component: () => import('../views/device/list.vue'),
        meta: {
          title: '设备异常',
        },
      },
    ]
  },
  {
    name: 'remoteControl',
    path: '/remoteControl',
    component: () => import('../views/remoteControl'),
    meta: {
      title: '远程管控',
    },
  },
]

const router = createRouter({
  history: createWebHashHistory(),
  routes
})
// 全局前置守卫，设置页面标题
router.beforeEach((to, from, next) => {
  // const title = to.meta && to.meta.title;
  // if (title) {
  //   document.title = title;
  // }
  document.title = '双碳感知资产运营管理平台';
  next(); //必须写
});

export default router
